==> jwinner-base-0.0.5-sources.jar: itez/plat/site/model/base/BaseNaviItem.java <==
package itez.plat.site.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseNaviItem<M extends BaseNaviItem<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setNaviId(java.lang.String naviId) {
		set("naviId", naviId);
		return (M)this;
	}
	
	public java.lang.String getNaviId() {
		return getStr("naviId");
	}

	public M setChannelId(java.lang.String channelId) {
		set("channelId", channelId);
		return (M)this;
	}
	
	public java.lang.String getChannelId() {
		return getStr("channelId");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setHref(java.lang.String href) {
		set("href", href);
		return (M)this;
	}
	
	public java.lang.String getHref() {
		return getStr("href");
	}

	public M setTarget(java.lang.String target) {
		set("target", target);
		return (M)this;
	}
	
	public java.lang.String getTarget() {
		return getStr("target");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

}

==> jwinner-base-0.1.7-sources.jar: itez/plat/site/model/base/BaseNaviItem.java <==
package itez.plat.site.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseNaviItem<M extends BaseNaviItem<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setSubDomain(java.lang.String subDomain) {
		set("subDomain", subDomain);
		return (M)this;
	}
	
	public java.lang.String getSubDomain() {
		return getStr("subDomain");
	}

	public M setNaviId(java.lang.String naviId) {
		set("naviId", naviId);
		return (M)this;
	}
	
	public java.lang.String getNaviId() {
		return getStr("naviId");
	}

	public M setChannelId(java.lang.String channelId) {
		set("channelId", channelId);
		return (M)this;
	}
	
	public java.lang.String getChannelId() {
		return getStr("channelId");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setIcon(java.lang.String icon) {
		set("icon", icon);
		return (M)this;
	}
	
	public java.lang.String getIcon() {
		return getStr("icon");
	}

	public M setHref(java.lang.String href) {
		set("href", href);
		return (M)this;
	}
	
	public java.lang.String getHref() {
		return getStr("href");
	}

	public M setTarget(java.lang.String target) {
		set("target", target);
		return (M)this;
	}
	
	public java.lang.String getTarget() {
		return getStr("target");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

}
